# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: transaction.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .waves import amount_pb2 as waves_dot_amount__pb2
from .waves import recipient_pb2 as waves_dot_recipient__pb2
from .waves import order_pb2 as waves_dot_order__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='transaction.proto',
  package='waves',
  syntax='proto3',
  serialized_pb=_b('\n\x11transaction.proto\x12\x05waves\x1a\x12waves/amount.proto\x1a\x15waves/recipient.proto\x1a\x11waves/order.proto\"L\n\x11SignedTransaction\x12\'\n\x0btransaction\x18\x01 \x01(\x0b\x32\x12.waves.Transaction\x12\x0e\n\x06proofs\x18\x02 \x03(\x0c\"\xa6\x08\n\x0bTransaction\x12\x10\n\x08\x63hain_id\x18\x01 \x01(\x05\x12\x19\n\x11sender_public_key\x18\x02 \x01(\x0c\x12\x1a\n\x03\x66\x65\x65\x18\x03 \x01(\x0b\x32\r.waves.Amount\x12\x11\n\ttimestamp\x18\x04 \x01(\x03\x12\x0f\n\x07version\x18\x05 \x01(\x05\x12\x30\n\x07genesis\x18\x65 \x01(\x0b\x32\x1d.waves.GenesisTransactionDataH\x00\x12\x30\n\x07payment\x18\x66 \x01(\x0b\x32\x1d.waves.PaymentTransactionDataH\x00\x12,\n\x05issue\x18g \x01(\x0b\x32\x1b.waves.IssueTransactionDataH\x00\x12\x32\n\x08transfer\x18h \x01(\x0b\x32\x1e.waves.TransferTransactionDataH\x00\x12\x30\n\x07reissue\x18i \x01(\x0b\x32\x1d.waves.ReissueTransactionDataH\x00\x12*\n\x04\x62urn\x18j \x01(\x0b\x32\x1a.waves.BurnTransactionDataH\x00\x12\x32\n\x08\x65xchange\x18k \x01(\x0b\x32\x1e.waves.ExchangeTransactionDataH\x00\x12,\n\x05lease\x18l \x01(\x0b\x32\x1b.waves.LeaseTransactionDataH\x00\x12\x39\n\x0clease_cancel\x18m \x01(\x0b\x32!.waves.LeaseCancelTransactionDataH\x00\x12\x39\n\x0c\x63reate_alias\x18n \x01(\x0b\x32!.waves.CreateAliasTransactionDataH\x00\x12;\n\rmass_transfer\x18o \x01(\x0b\x32\".waves.MassTransferTransactionDataH\x00\x12\x36\n\x10\x64\x61ta_transaction\x18p \x01(\x0b\x32\x1a.waves.DataTransactionDataH\x00\x12\x35\n\nset_script\x18q \x01(\x0b\x32\x1f.waves.SetScriptTransactionDataH\x00\x12\x37\n\x0bsponsor_fee\x18r \x01(\x0b\x32 .waves.SponsorFeeTransactionDataH\x00\x12@\n\x10set_asset_script\x18s \x01(\x0b\x32$.waves.SetAssetScriptTransactionDataH\x00\x12;\n\rinvoke_script\x18t \x01(\x0b\x32\".waves.InvokeScriptTransactionDataH\x00\x12\x42\n\x11update_asset_info\x18u \x01(\x0b\x32%.waves.UpdateAssetInfoTransactionDataH\x00\x42\x06\n\x04\x64\x61ta\"C\n\x16GenesisTransactionData\x12\x19\n\x11recipient_address\x18\x01 \x01(\x0c\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x03\"C\n\x16PaymentTransactionData\x12\x19\n\x11recipient_address\x18\x01 \x01(\x0c\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x03\"u\n\nAttachment\x12\x13\n\tint_value\x18\x01 \x01(\x03H\x00\x12\x14\n\nbool_value\x18\x02 \x01(\x08H\x00\x12\x16\n\x0c\x62inary_value\x18\x03 \x01(\x0cH\x00\x12\x16\n\x0cstring_value\x18\x04 \x01(\tH\x00\x42\x0c\n\nattachment\"\x84\x01\n\x17TransferTransactionData\x12#\n\trecipient\x18\x01 \x01(\x0b\x32\x10.waves.Recipient\x12\x1d\n\x06\x61mount\x18\x02 \x01(\x0b\x32\r.waves.Amount\x12%\n\nattachment\x18\x03 \x01(\x0b\x32\x11.waves.Attachment\"+\n\x1a\x43reateAliasTransactionData\x12\r\n\x05\x61lias\x18\x01 \x01(\t\"\xc7\x01\n\x13\x44\x61taTransactionData\x12\x32\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32$.waves.DataTransactionData.DataEntry\x1a|\n\tDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x13\n\tint_value\x18\n \x01(\x03H\x00\x12\x14\n\nbool_value\x18\x0b \x01(\x08H\x00\x12\x16\n\x0c\x62inary_value\x18\x0c \x01(\x0cH\x00\x12\x16\n\x0cstring_value\x18\r \x01(\tH\x00\x42\x07\n\x05value\"\xd7\x01\n\x1bMassTransferTransactionData\x12\x10\n\x08\x61sset_id\x18\x01 \x01(\x0c\x12>\n\ttransfers\x18\x02 \x03(\x0b\x32+.waves.MassTransferTransactionData.Transfer\x12%\n\nattachment\x18\x03 \x01(\x0b\x32\x11.waves.Attachment\x1a?\n\x08Transfer\x12#\n\trecipient\x18\x01 \x01(\x0b\x32\x10.waves.Recipient\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x03\"K\n\x14LeaseTransactionData\x12#\n\trecipient\x18\x01 \x01(\x0b\x32\x10.waves.Recipient\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x03\".\n\x1aLeaseCancelTransactionData\x12\x10\n\x08lease_id\x18\x01 \x01(\x0c\":\n\x13\x42urnTransactionData\x12#\n\x0c\x61sset_amount\x18\x01 \x01(\x0b\x32\r.waves.Amount\"\x7f\n\x14IssueTransactionData\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x03\x12\x10\n\x08\x64\x65\x63imals\x18\x04 \x01(\x05\x12\x12\n\nreissuable\x18\x05 \x01(\x08\x12\x0e\n\x06script\x18\x06 \x01(\x0c\"Q\n\x16ReissueTransactionData\x12#\n\x0c\x61sset_amount\x18\x01 \x01(\x0b\x32\r.waves.Amount\x12\x12\n\nreissuable\x18\x02 \x01(\x08\"A\n\x1dSetAssetScriptTransactionData\x12\x10\n\x08\x61sset_id\x18\x01 \x01(\x0c\x12\x0e\n\x06script\x18\x02 \x01(\x0c\"*\n\x18SetScriptTransactionData\x12\x0e\n\x06script\x18\x01 \x01(\x0c\"\x89\x01\n\x17\x45xchangeTransactionData\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x03\x12\r\n\x05price\x18\x02 \x01(\x03\x12\x17\n\x0f\x62uy_matcher_fee\x18\x03 \x01(\x03\x12\x18\n\x10sell_matcher_fee\x18\x04 \x01(\x03\x12\x1c\n\x06orders\x18\x05 \x03(\x0b\x32\x0c.waves.Order\";\n\x19SponsorFeeTransactionData\x12\x1e\n\x07min_fee\x18\x01 \x01(\x0b\x32\r.waves.Amount\"v\n\x1bInvokeScriptTransactionData\x12\x1f\n\x05\x64_app\x18\x01 \x01(\x0b\x32\x10.waves.Recipient\x12\x15\n\rfunction_call\x18\x02 \x01(\x0c\x12\x1f\n\x08payments\x18\x03 \x03(\x0b\x32\r.waves.Amount\"U\n\x1eUpdateAssetInfoTransactionData\x12\x10\n\x08\x61sset_id\x18\x01 \x01(\x0c\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\tB0\n&com.wavesplatform.protobuf.transaction\xaa\x02\x05Wavesb\x06proto3')
  ,
  dependencies=[waves_dot_amount__pb2.DESCRIPTOR,waves_dot_recipient__pb2.DESCRIPTOR,waves_dot_order__pb2.DESCRIPTOR,])




_SIGNEDTRANSACTION = _descriptor.Descriptor(
  name='SignedTransaction',
  full_name='waves.SignedTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction', full_name='waves.SignedTransaction.transaction', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='proofs', full_name='waves.SignedTransaction.proofs', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=166,
)


_TRANSACTION = _descriptor.Descriptor(
  name='Transaction',
  full_name='waves.Transaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chain_id', full_name='waves.Transaction.chain_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sender_public_key', full_name='waves.Transaction.sender_public_key', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fee', full_name='waves.Transaction.fee', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='waves.Transaction.timestamp', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='version', full_name='waves.Transaction.version', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='genesis', full_name='waves.Transaction.genesis', index=5,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='payment', full_name='waves.Transaction.payment', index=6,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='issue', full_name='waves.Transaction.issue', index=7,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='transfer', full_name='waves.Transaction.transfer', index=8,
      number=104, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reissue', full_name='waves.Transaction.reissue', index=9,
      number=105, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='burn', full_name='waves.Transaction.burn', index=10,
      number=106, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='waves.Transaction.exchange', index=11,
      number=107, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lease', full_name='waves.Transaction.lease', index=12,
      number=108, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lease_cancel', full_name='waves.Transaction.lease_cancel', index=13,
      number=109, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='create_alias', full_name='waves.Transaction.create_alias', index=14,
      number=110, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mass_transfer', full_name='waves.Transaction.mass_transfer', index=15,
      number=111, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data_transaction', full_name='waves.Transaction.data_transaction', index=16,
      number=112, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='set_script', full_name='waves.Transaction.set_script', index=17,
      number=113, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sponsor_fee', full_name='waves.Transaction.sponsor_fee', index=18,
      number=114, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='set_asset_script', full_name='waves.Transaction.set_asset_script', index=19,
      number=115, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='invoke_script', full_name='waves.Transaction.invoke_script', index=20,
      number=116, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='update_asset_info', full_name='waves.Transaction.update_asset_info', index=21,
      number=117, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='waves.Transaction.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=169,
  serialized_end=1231,
)


_GENESISTRANSACTIONDATA = _descriptor.Descriptor(
  name='GenesisTransactionData',
  full_name='waves.GenesisTransactionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recipient_address', full_name='waves.GenesisTransactionData.recipient_address', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amount', full_name='waves.GenesisTransactionData.amount', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1233,
  serialized_end=1300,
)


_PAYMENTTRANSACTIONDATA = _descriptor.Descriptor(
  name='PaymentTransactionData',
  full_name='waves.PaymentTransactionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recipient_address', full_name='waves.PaymentTransactionData.recipient_address', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amount', full_name='waves.PaymentTransactionData.amount', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1302,
  serialized_end=1369,
)


_ATTACHMENT = _descriptor.Descriptor(
  name='Attachment',
  full_name='waves.Attachment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='int_value', full_name='waves.Attachment.int_value', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bool_value', full_name='waves.Attachment.bool_value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='binary_value', full_name='waves.Attachment.binary_value', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='waves.Attachment.string_value', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='attachment', full_name='waves.Attachment.attachment',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1371,
  serialized_end=1488,
)


_TRANSFERTRANSACTIONDATA = _descriptor.Descriptor(
  name='TransferTransactionData',
  full_name='waves.TransferTransactionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recipient', full_name='waves.TransferTransactionData.recipient', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amount', full_name='waves.TransferTransactionData.amount', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attachment', full_name='waves.TransferTransactionData.attachment', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1491,
  serialized_end=1623,
)


_CREATEALIASTRANSACTIONDATA = _descriptor.Descriptor(
  name='CreateAliasTransactionData',
  full_name='waves.CreateAliasTransactionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='alias', full_name='waves.CreateAliasTransactionData.alias', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1625,
  serialized_end=1668,
)


_DATATRANSACTIONDATA_DATAENTRY = _descriptor.Descriptor(
  name='DataEntry',
  full_name='waves.DataTransactionData.DataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='waves.DataTransactionData.DataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='int_value', full_name='waves.DataTransactionData.DataEntry.int_value', index=1,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bool_value', full_name='waves.DataTransactionData.DataEntry.bool_value', index=2,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='binary_value', full_name='waves.DataTransactionData.DataEntry.binary_value', index=3,
      number=12, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='waves.DataTransactionData.DataEntry.string_value', index=4,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='waves.DataTransactionData.DataEntry.value',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1746,
  serialized_end=1870,
)

_DATATRANSACTIONDATA = _descriptor.Descriptor(
  name='DataTransactionData',
  full_name='waves.DataTransactionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='waves.DataTransactionData.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_DATATRANSACTIONDATA_DATAENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1671,
  serialized_end=1870,
)


_MASSTRANSFERTRANSACTIONDATA_TRANSFER = _descriptor.Descriptor(
  name='Transfer',
  full_name='waves.MassTransferTransactionData.Transfer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recipient', full_name='waves.MassTransferTransactionData.Transfer.recipient', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amount', full_name='waves.MassTransferTransactionData.Transfer.amount', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2025,
  serialized_end=2088,
)

_MASSTRANSFERTRANSACTIONDATA = _descriptor.Descriptor(
  name='MassTransferTransactionData',
  full_name='waves.MassTransferTransactionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='asset_id', full_name='waves.MassTransferTransactionData.asset_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='transfers', full_name='waves.MassTransferTransactionData.transfers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attachment', full_name='waves.MassTransferTransactionData.attachment', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_MASSTRANSFERTRANSACTIONDATA_TRANSFER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1873,
  serialized_end=2088,
)


_LEASETRANSACTIONDATA = _descriptor.Descriptor(
  name='LeaseTransactionData',
  full_name='waves.LeaseTransactionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recipient', full_name='waves.LeaseTransactionData.recipient', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amount', full_name='waves.LeaseTransactionData.amount', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2090,
  serialized_end=2165,
)


_LEASECANCELTRANSACTIONDATA = _descriptor.Descriptor(
  name='LeaseCancelTransactionData',
  full_name='waves.LeaseCancelTransactionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lease_id', full_name='waves.LeaseCancelTransactionData.lease_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2167,
  serialized_end=2213,
)


_BURNTRANSACTIONDATA = _descriptor.Descriptor(
  name='BurnTransactionData',
  full_name='waves.BurnTransactionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='asset_amount', full_name='waves.BurnTransactionData.asset_amount', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2215,
  serialized_end=2273,
)


_ISSUETRANSACTIONDATA = _descriptor.Descriptor(
  name='IssueTransactionData',
  full_name='waves.IssueTransactionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='waves.IssueTransactionData.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='waves.IssueTransactionData.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amount', full_name='waves.IssueTransactionData.amount', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='decimals', full_name='waves.IssueTransactionData.decimals', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reissuable', full_name='waves.IssueTransactionData.reissuable', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='script', full_name='waves.IssueTransactionData.script', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2275,
  serialized_end=2402,
)


_REISSUETRANSACTIONDATA = _descriptor.Descriptor(
  name='ReissueTransactionData',
  full_name='waves.ReissueTransactionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='asset_amount', full_name='waves.ReissueTransactionData.asset_amount', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reissuable', full_name='waves.ReissueTransactionData.reissuable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2404,
  serialized_end=2485,
)


_SETASSETSCRIPTTRANSACTIONDATA = _descriptor.Descriptor(
  name='SetAssetScriptTransactionData',
  full_name='waves.SetAssetScriptTransactionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='asset_id', full_name='waves.SetAssetScriptTransactionData.asset_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='script', full_name='waves.SetAssetScriptTransactionData.script', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2487,
  serialized_end=2552,
)


_SETSCRIPTTRANSACTIONDATA = _descriptor.Descriptor(
  name='SetScriptTransactionData',
  full_name='waves.SetScriptTransactionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='script', full_name='waves.SetScriptTransactionData.script', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2554,
  serialized_end=2596,
)


_EXCHANGETRANSACTIONDATA = _descriptor.Descriptor(
  name='ExchangeTransactionData',
  full_name='waves.ExchangeTransactionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='waves.ExchangeTransactionData.amount', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='price', full_name='waves.ExchangeTransactionData.price', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='buy_matcher_fee', full_name='waves.ExchangeTransactionData.buy_matcher_fee', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sell_matcher_fee', full_name='waves.ExchangeTransactionData.sell_matcher_fee', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='orders', full_name='waves.ExchangeTransactionData.orders', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2599,
  serialized_end=2736,
)


_SPONSORFEETRANSACTIONDATA = _descriptor.Descriptor(
  name='SponsorFeeTransactionData',
  full_name='waves.SponsorFeeTransactionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_fee', full_name='waves.SponsorFeeTransactionData.min_fee', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2738,
  serialized_end=2797,
)


_INVOKESCRIPTTRANSACTIONDATA = _descriptor.Descriptor(
  name='InvokeScriptTransactionData',
  full_name='waves.InvokeScriptTransactionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='d_app', full_name='waves.InvokeScriptTransactionData.d_app', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='function_call', full_name='waves.InvokeScriptTransactionData.function_call', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='payments', full_name='waves.InvokeScriptTransactionData.payments', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2799,
  serialized_end=2917,
)


_UPDATEASSETINFOTRANSACTIONDATA = _descriptor.Descriptor(
  name='UpdateAssetInfoTransactionData',
  full_name='waves.UpdateAssetInfoTransactionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='asset_id', full_name='waves.UpdateAssetInfoTransactionData.asset_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='waves.UpdateAssetInfoTransactionData.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='waves.UpdateAssetInfoTransactionData.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2919,
  serialized_end=3004,
)

_SIGNEDTRANSACTION.fields_by_name['transaction'].message_type = _TRANSACTION
_TRANSACTION.fields_by_name['fee'].message_type = waves_dot_amount__pb2._AMOUNT
_TRANSACTION.fields_by_name['genesis'].message_type = _GENESISTRANSACTIONDATA
_TRANSACTION.fields_by_name['payment'].message_type = _PAYMENTTRANSACTIONDATA
_TRANSACTION.fields_by_name['issue'].message_type = _ISSUETRANSACTIONDATA
_TRANSACTION.fields_by_name['transfer'].message_type = _TRANSFERTRANSACTIONDATA
_TRANSACTION.fields_by_name['reissue'].message_type = _REISSUETRANSACTIONDATA
_TRANSACTION.fields_by_name['burn'].message_type = _BURNTRANSACTIONDATA
_TRANSACTION.fields_by_name['exchange'].message_type = _EXCHANGETRANSACTIONDATA
_TRANSACTION.fields_by_name['lease'].message_type = _LEASETRANSACTIONDATA
_TRANSACTION.fields_by_name['lease_cancel'].message_type = _LEASECANCELTRANSACTIONDATA
_TRANSACTION.fields_by_name['create_alias'].message_type = _CREATEALIASTRANSACTIONDATA
_TRANSACTION.fields_by_name['mass_transfer'].message_type = _MASSTRANSFERTRANSACTIONDATA
_TRANSACTION.fields_by_name['data_transaction'].message_type = _DATATRANSACTIONDATA
_TRANSACTION.fields_by_name['set_script'].message_type = _SETSCRIPTTRANSACTIONDATA
_TRANSACTION.fields_by_name['sponsor_fee'].message_type = _SPONSORFEETRANSACTIONDATA
_TRANSACTION.fields_by_name['set_asset_script'].message_type = _SETASSETSCRIPTTRANSACTIONDATA
_TRANSACTION.fields_by_name['invoke_script'].message_type = _INVOKESCRIPTTRANSACTIONDATA
_TRANSACTION.fields_by_name['update_asset_info'].message_type = _UPDATEASSETINFOTRANSACTIONDATA
_TRANSACTION.oneofs_by_name['data'].fields.append(
  _TRANSACTION.fields_by_name['genesis'])
_TRANSACTION.fields_by_name['genesis'].containing_oneof = _TRANSACTION.oneofs_by_name['data']
_TRANSACTION.oneofs_by_name['data'].fields.append(
  _TRANSACTION.fields_by_name['payment'])
_TRANSACTION.fields_by_name['payment'].containing_oneof = _TRANSACTION.oneofs_by_name['data']
_TRANSACTION.oneofs_by_name['data'].fields.append(
  _TRANSACTION.fields_by_name['issue'])
_TRANSACTION.fields_by_name['issue'].containing_oneof = _TRANSACTION.oneofs_by_name['data']
_TRANSACTION.oneofs_by_name['data'].fields.append(
  _TRANSACTION.fields_by_name['transfer'])
_TRANSACTION.fields_by_name['transfer'].containing_oneof = _TRANSACTION.oneofs_by_name['data']
_TRANSACTION.oneofs_by_name['data'].fields.append(
  _TRANSACTION.fields_by_name['reissue'])
_TRANSACTION.fields_by_name['reissue'].containing_oneof = _TRANSACTION.oneofs_by_name['data']
_TRANSACTION.oneofs_by_name['data'].fields.append(
  _TRANSACTION.fields_by_name['burn'])
_TRANSACTION.fields_by_name['burn'].containing_oneof = _TRANSACTION.oneofs_by_name['data']
_TRANSACTION.oneofs_by_name['data'].fields.append(
  _TRANSACTION.fields_by_name['exchange'])
_TRANSACTION.fields_by_name['exchange'].containing_oneof = _TRANSACTION.oneofs_by_name['data']
_TRANSACTION.oneofs_by_name['data'].fields.append(
  _TRANSACTION.fields_by_name['lease'])
_TRANSACTION.fields_by_name['lease'].containing_oneof = _TRANSACTION.oneofs_by_name['data']
_TRANSACTION.oneofs_by_name['data'].fields.append(
  _TRANSACTION.fields_by_name['lease_cancel'])
_TRANSACTION.fields_by_name['lease_cancel'].containing_oneof = _TRANSACTION.oneofs_by_name['data']
_TRANSACTION.oneofs_by_name['data'].fields.append(
  _TRANSACTION.fields_by_name['create_alias'])
_TRANSACTION.fields_by_name['create_alias'].containing_oneof = _TRANSACTION.oneofs_by_name['data']
_TRANSACTION.oneofs_by_name['data'].fields.append(
  _TRANSACTION.fields_by_name['mass_transfer'])
_TRANSACTION.fields_by_name['mass_transfer'].containing_oneof = _TRANSACTION.oneofs_by_name['data']
_TRANSACTION.oneofs_by_name['data'].fields.append(
  _TRANSACTION.fields_by_name['data_transaction'])
_TRANSACTION.fields_by_name['data_transaction'].containing_oneof = _TRANSACTION.oneofs_by_name['data']
_TRANSACTION.oneofs_by_name['data'].fields.append(
  _TRANSACTION.fields_by_name['set_script'])
_TRANSACTION.fields_by_name['set_script'].containing_oneof = _TRANSACTION.oneofs_by_name['data']
_TRANSACTION.oneofs_by_name['data'].fields.append(
  _TRANSACTION.fields_by_name['sponsor_fee'])
_TRANSACTION.fields_by_name['sponsor_fee'].containing_oneof = _TRANSACTION.oneofs_by_name['data']
_TRANSACTION.oneofs_by_name['data'].fields.append(
  _TRANSACTION.fields_by_name['set_asset_script'])
_TRANSACTION.fields_by_name['set_asset_script'].containing_oneof = _TRANSACTION.oneofs_by_name['data']
_TRANSACTION.oneofs_by_name['data'].fields.append(
  _TRANSACTION.fields_by_name['invoke_script'])
_TRANSACTION.fields_by_name['invoke_script'].containing_oneof = _TRANSACTION.oneofs_by_name['data']
_TRANSACTION.oneofs_by_name['data'].fields.append(
  _TRANSACTION.fields_by_name['update_asset_info'])
_TRANSACTION.fields_by_name['update_asset_info'].containing_oneof = _TRANSACTION.oneofs_by_name['data']
_ATTACHMENT.oneofs_by_name['attachment'].fields.append(
  _ATTACHMENT.fields_by_name['int_value'])
_ATTACHMENT.fields_by_name['int_value'].containing_oneof = _ATTACHMENT.oneofs_by_name['attachment']
_ATTACHMENT.oneofs_by_name['attachment'].fields.append(
  _ATTACHMENT.fields_by_name['bool_value'])
_ATTACHMENT.fields_by_name['bool_value'].containing_oneof = _ATTACHMENT.oneofs_by_name['attachment']
_ATTACHMENT.oneofs_by_name['attachment'].fields.append(
  _ATTACHMENT.fields_by_name['binary_value'])
_ATTACHMENT.fields_by_name['binary_value'].containing_oneof = _ATTACHMENT.oneofs_by_name['attachment']
_ATTACHMENT.oneofs_by_name['attachment'].fields.append(
  _ATTACHMENT.fields_by_name['string_value'])
_ATTACHMENT.fields_by_name['string_value'].containing_oneof = _ATTACHMENT.oneofs_by_name['attachment']
_TRANSFERTRANSACTIONDATA.fields_by_name['recipient'].message_type = waves_dot_recipient__pb2._RECIPIENT
_TRANSFERTRANSACTIONDATA.fields_by_name['amount'].message_type = waves_dot_amount__pb2._AMOUNT
_TRANSFERTRANSACTIONDATA.fields_by_name['attachment'].message_type = _ATTACHMENT
_DATATRANSACTIONDATA_DATAENTRY.containing_type = _DATATRANSACTIONDATA
_DATATRANSACTIONDATA_DATAENTRY.oneofs_by_name['value'].fields.append(
  _DATATRANSACTIONDATA_DATAENTRY.fields_by_name['int_value'])
_DATATRANSACTIONDATA_DATAENTRY.fields_by_name['int_value'].containing_oneof = _DATATRANSACTIONDATA_DATAENTRY.oneofs_by_name['value']
_DATATRANSACTIONDATA_DATAENTRY.oneofs_by_name['value'].fields.append(
  _DATATRANSACTIONDATA_DATAENTRY.fields_by_name['bool_value'])
_DATATRANSACTIONDATA_DATAENTRY.fields_by_name['bool_value'].containing_oneof = _DATATRANSACTIONDATA_DATAENTRY.oneofs_by_name['value']
_DATATRANSACTIONDATA_DATAENTRY.oneofs_by_name['value'].fields.append(
  _DATATRANSACTIONDATA_DATAENTRY.fields_by_name['binary_value'])
_DATATRANSACTIONDATA_DATAENTRY.fields_by_name['binary_value'].containing_oneof = _DATATRANSACTIONDATA_DATAENTRY.oneofs_by_name['value']
_DATATRANSACTIONDATA_DATAENTRY.oneofs_by_name['value'].fields.append(
  _DATATRANSACTIONDATA_DATAENTRY.fields_by_name['string_value'])
_DATATRANSACTIONDATA_DATAENTRY.fields_by_name['string_value'].containing_oneof = _DATATRANSACTIONDATA_DATAENTRY.oneofs_by_name['value']
_DATATRANSACTIONDATA.fields_by_name['data'].message_type = _DATATRANSACTIONDATA_DATAENTRY
_MASSTRANSFERTRANSACTIONDATA_TRANSFER.fields_by_name['recipient'].message_type = waves_dot_recipient__pb2._RECIPIENT
_MASSTRANSFERTRANSACTIONDATA_TRANSFER.containing_type = _MASSTRANSFERTRANSACTIONDATA
_MASSTRANSFERTRANSACTIONDATA.fields_by_name['transfers'].message_type = _MASSTRANSFERTRANSACTIONDATA_TRANSFER
_MASSTRANSFERTRANSACTIONDATA.fields_by_name['attachment'].message_type = _ATTACHMENT
_LEASETRANSACTIONDATA.fields_by_name['recipient'].message_type = waves_dot_recipient__pb2._RECIPIENT
_BURNTRANSACTIONDATA.fields_by_name['asset_amount'].message_type = waves_dot_amount__pb2._AMOUNT
_REISSUETRANSACTIONDATA.fields_by_name['asset_amount'].message_type = waves_dot_amount__pb2._AMOUNT
_EXCHANGETRANSACTIONDATA.fields_by_name['orders'].message_type = waves_dot_order__pb2._ORDER
_SPONSORFEETRANSACTIONDATA.fields_by_name['min_fee'].message_type = waves_dot_amount__pb2._AMOUNT
_INVOKESCRIPTTRANSACTIONDATA.fields_by_name['d_app'].message_type = waves_dot_recipient__pb2._RECIPIENT
_INVOKESCRIPTTRANSACTIONDATA.fields_by_name['payments'].message_type = waves_dot_amount__pb2._AMOUNT
DESCRIPTOR.message_types_by_name['SignedTransaction'] = _SIGNEDTRANSACTION
DESCRIPTOR.message_types_by_name['Transaction'] = _TRANSACTION
DESCRIPTOR.message_types_by_name['GenesisTransactionData'] = _GENESISTRANSACTIONDATA
DESCRIPTOR.message_types_by_name['PaymentTransactionData'] = _PAYMENTTRANSACTIONDATA
DESCRIPTOR.message_types_by_name['Attachment'] = _ATTACHMENT
DESCRIPTOR.message_types_by_name['TransferTransactionData'] = _TRANSFERTRANSACTIONDATA
DESCRIPTOR.message_types_by_name['CreateAliasTransactionData'] = _CREATEALIASTRANSACTIONDATA
DESCRIPTOR.message_types_by_name['DataTransactionData'] = _DATATRANSACTIONDATA
DESCRIPTOR.message_types_by_name['MassTransferTransactionData'] = _MASSTRANSFERTRANSACTIONDATA
DESCRIPTOR.message_types_by_name['LeaseTransactionData'] = _LEASETRANSACTIONDATA
DESCRIPTOR.message_types_by_name['LeaseCancelTransactionData'] = _LEASECANCELTRANSACTIONDATA
DESCRIPTOR.message_types_by_name['BurnTransactionData'] = _BURNTRANSACTIONDATA
DESCRIPTOR.message_types_by_name['IssueTransactionData'] = _ISSUETRANSACTIONDATA
DESCRIPTOR.message_types_by_name['ReissueTransactionData'] = _REISSUETRANSACTIONDATA
DESCRIPTOR.message_types_by_name['SetAssetScriptTransactionData'] = _SETASSETSCRIPTTRANSACTIONDATA
DESCRIPTOR.message_types_by_name['SetScriptTransactionData'] = _SETSCRIPTTRANSACTIONDATA
DESCRIPTOR.message_types_by_name['ExchangeTransactionData'] = _EXCHANGETRANSACTIONDATA
DESCRIPTOR.message_types_by_name['SponsorFeeTransactionData'] = _SPONSORFEETRANSACTIONDATA
DESCRIPTOR.message_types_by_name['InvokeScriptTransactionData'] = _INVOKESCRIPTTRANSACTIONDATA
DESCRIPTOR.message_types_by_name['UpdateAssetInfoTransactionData'] = _UPDATEASSETINFOTRANSACTIONDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SignedTransaction = _reflection.GeneratedProtocolMessageType('SignedTransaction', (_message.Message,), dict(
  DESCRIPTOR = _SIGNEDTRANSACTION,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:waves.SignedTransaction)
  ))
_sym_db.RegisterMessage(SignedTransaction)

Transaction = _reflection.GeneratedProtocolMessageType('Transaction', (_message.Message,), dict(
  DESCRIPTOR = _TRANSACTION,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:waves.Transaction)
  ))
_sym_db.RegisterMessage(Transaction)

GenesisTransactionData = _reflection.GeneratedProtocolMessageType('GenesisTransactionData', (_message.Message,), dict(
  DESCRIPTOR = _GENESISTRANSACTIONDATA,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:waves.GenesisTransactionData)
  ))
_sym_db.RegisterMessage(GenesisTransactionData)

PaymentTransactionData = _reflection.GeneratedProtocolMessageType('PaymentTransactionData', (_message.Message,), dict(
  DESCRIPTOR = _PAYMENTTRANSACTIONDATA,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:waves.PaymentTransactionData)
  ))
_sym_db.RegisterMessage(PaymentTransactionData)

Attachment = _reflection.GeneratedProtocolMessageType('Attachment', (_message.Message,), dict(
  DESCRIPTOR = _ATTACHMENT,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:waves.Attachment)
  ))
_sym_db.RegisterMessage(Attachment)

TransferTransactionData = _reflection.GeneratedProtocolMessageType('TransferTransactionData', (_message.Message,), dict(
  DESCRIPTOR = _TRANSFERTRANSACTIONDATA,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:waves.TransferTransactionData)
  ))
_sym_db.RegisterMessage(TransferTransactionData)

CreateAliasTransactionData = _reflection.GeneratedProtocolMessageType('CreateAliasTransactionData', (_message.Message,), dict(
  DESCRIPTOR = _CREATEALIASTRANSACTIONDATA,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:waves.CreateAliasTransactionData)
  ))
_sym_db.RegisterMessage(CreateAliasTransactionData)

DataTransactionData = _reflection.GeneratedProtocolMessageType('DataTransactionData', (_message.Message,), dict(

  DataEntry = _reflection.GeneratedProtocolMessageType('DataEntry', (_message.Message,), dict(
    DESCRIPTOR = _DATATRANSACTIONDATA_DATAENTRY,
    __module__ = 'transaction_pb2'
    # @@protoc_insertion_point(class_scope:waves.DataTransactionData.DataEntry)
    ))
  ,
  DESCRIPTOR = _DATATRANSACTIONDATA,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:waves.DataTransactionData)
  ))
_sym_db.RegisterMessage(DataTransactionData)
_sym_db.RegisterMessage(DataTransactionData.DataEntry)

MassTransferTransactionData = _reflection.GeneratedProtocolMessageType('MassTransferTransactionData', (_message.Message,), dict(

  Transfer = _reflection.GeneratedProtocolMessageType('Transfer', (_message.Message,), dict(
    DESCRIPTOR = _MASSTRANSFERTRANSACTIONDATA_TRANSFER,
    __module__ = 'transaction_pb2'
    # @@protoc_insertion_point(class_scope:waves.MassTransferTransactionData.Transfer)
    ))
  ,
  DESCRIPTOR = _MASSTRANSFERTRANSACTIONDATA,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:waves.MassTransferTransactionData)
  ))
_sym_db.RegisterMessage(MassTransferTransactionData)
_sym_db.RegisterMessage(MassTransferTransactionData.Transfer)

LeaseTransactionData = _reflection.GeneratedProtocolMessageType('LeaseTransactionData', (_message.Message,), dict(
  DESCRIPTOR = _LEASETRANSACTIONDATA,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:waves.LeaseTransactionData)
  ))
_sym_db.RegisterMessage(LeaseTransactionData)

LeaseCancelTransactionData = _reflection.GeneratedProtocolMessageType('LeaseCancelTransactionData', (_message.Message,), dict(
  DESCRIPTOR = _LEASECANCELTRANSACTIONDATA,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:waves.LeaseCancelTransactionData)
  ))
_sym_db.RegisterMessage(LeaseCancelTransactionData)

BurnTransactionData = _reflection.GeneratedProtocolMessageType('BurnTransactionData', (_message.Message,), dict(
  DESCRIPTOR = _BURNTRANSACTIONDATA,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:waves.BurnTransactionData)
  ))
_sym_db.RegisterMessage(BurnTransactionData)

IssueTransactionData = _reflection.GeneratedProtocolMessageType('IssueTransactionData', (_message.Message,), dict(
  DESCRIPTOR = _ISSUETRANSACTIONDATA,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:waves.IssueTransactionData)
  ))
_sym_db.RegisterMessage(IssueTransactionData)

ReissueTransactionData = _reflection.GeneratedProtocolMessageType('ReissueTransactionData', (_message.Message,), dict(
  DESCRIPTOR = _REISSUETRANSACTIONDATA,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:waves.ReissueTransactionData)
  ))
_sym_db.RegisterMessage(ReissueTransactionData)

SetAssetScriptTransactionData = _reflection.GeneratedProtocolMessageType('SetAssetScriptTransactionData', (_message.Message,), dict(
  DESCRIPTOR = _SETASSETSCRIPTTRANSACTIONDATA,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:waves.SetAssetScriptTransactionData)
  ))
_sym_db.RegisterMessage(SetAssetScriptTransactionData)

SetScriptTransactionData = _reflection.GeneratedProtocolMessageType('SetScriptTransactionData', (_message.Message,), dict(
  DESCRIPTOR = _SETSCRIPTTRANSACTIONDATA,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:waves.SetScriptTransactionData)
  ))
_sym_db.RegisterMessage(SetScriptTransactionData)

ExchangeTransactionData = _reflection.GeneratedProtocolMessageType('ExchangeTransactionData', (_message.Message,), dict(
  DESCRIPTOR = _EXCHANGETRANSACTIONDATA,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:waves.ExchangeTransactionData)
  ))
_sym_db.RegisterMessage(ExchangeTransactionData)

SponsorFeeTransactionData = _reflection.GeneratedProtocolMessageType('SponsorFeeTransactionData', (_message.Message,), dict(
  DESCRIPTOR = _SPONSORFEETRANSACTIONDATA,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:waves.SponsorFeeTransactionData)
  ))
_sym_db.RegisterMessage(SponsorFeeTransactionData)

InvokeScriptTransactionData = _reflection.GeneratedProtocolMessageType('InvokeScriptTransactionData', (_message.Message,), dict(
  DESCRIPTOR = _INVOKESCRIPTTRANSACTIONDATA,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:waves.InvokeScriptTransactionData)
  ))
_sym_db.RegisterMessage(InvokeScriptTransactionData)

UpdateAssetInfoTransactionData = _reflection.GeneratedProtocolMessageType('UpdateAssetInfoTransactionData', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEASSETINFOTRANSACTIONDATA,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:waves.UpdateAssetInfoTransactionData)
  ))
_sym_db.RegisterMessage(UpdateAssetInfoTransactionData)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n&com.wavesplatform.protobuf.transaction\252\002\005Waves'))
# @@protoc_insertion_point(module_scope)
