# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: waves/amount.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='waves/amount.proto',
  package='waves',
  syntax='proto3',
  serialized_pb=_b('\n\x12waves/amount.proto\x12\x05waves\"*\n\x06\x41mount\x12\x10\n\x08\x61sset_id\x18\x01 \x01(\x0c\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x03\x42$\n\x1a\x63om.wavesplatform.protobuf\xaa\x02\x05Wavesb\x06proto3')
)




_AMOUNT = _descriptor.Descriptor(
  name='Amount',
  full_name='waves.Amount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='asset_id', full_name='waves.Amount.asset_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amount', full_name='waves.Amount.amount', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29,
  serialized_end=71,
)

DESCRIPTOR.message_types_by_name['Amount'] = _AMOUNT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Amount = _reflection.GeneratedProtocolMessageType('Amount', (_message.Message,), dict(
  DESCRIPTOR = _AMOUNT,
  __module__ = 'waves.amount_pb2'
  # @@protoc_insertion_point(class_scope:waves.Amount)
  ))
_sym_db.RegisterMessage(Amount)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\032com.wavesplatform.protobuf\252\002\005Waves'))
# @@protoc_insertion_point(module_scope)
